@@ -247,8 +247,6 @@ modifyWeights <- function(weights, status, values, multipliers)
 	weights
 }
 
-#	READ IMAGE ANALYSIS FILES INTO RG LIST
-
 read.matrix <- function(file,nrows=0,skip=0,...) {
 #	Read numeric matrix with headers from file
 #	Gordon Smyth
@@ -260,231 +258,6 @@ read.matrix <- function(file,nrows=0,skip=0,...) {
 	x
 }
 
-read.maimages <- function(files,source=NULL,path=NULL,ext=NULL,names=NULL,columns=NULL,other.columns=NULL,annotation=NULL,wt.fun=NULL,verbose=TRUE,sep="\t",quote="\"",...) {
-#	Extracts an RG list from a series of image analysis output files
-#	Gordon Smyth
-#	1 Nov 2002.  Last revised 26 August 2005.
-
-	if(missing(files)) {
-		if(missing(ext))
-			stop("Must specify input files")
-		else {
-			extregex <- paste("\\.",ext,"$",sep="")
-			files <- dir(path=ifelse(is.null(path),".",path),pattern=extregex)
-			files <- sub(extregex,"",files)
-		}
-	}
-	if(is.null(source)) {
-		source <- "generic"
-	} else {
-		source <- match.arg(source,c("agilent","arrayvision","bluefuse","genepix","genepix.median","genepix.custom","imagene","quantarray","smd.old","smd","spot","spot.close.open"))
-		if(source=="imagene") return(read.imagene(files=files,path=path,ext=ext,names=names,columns=columns,wt.fun=wt.fun,verbose=verbose,sep=sep,quote=quote,...))
-	}
-	slides <- as.vector(as.character(files))
-	if(!is.null(ext)) slides <- paste(slides,ext,sep=".")
-	nslides <- length(slides)
-	if(is.null(names)) names <- removeExt(files)
-
-	if(is.null(columns)) {
-		if(is.null(source)) stop("At least one of 'source' or 'columns' must be given")
-		columns <- switch(source,
-			agilent = list(G="gMeanSignal",Gb="gBGMedianSignal",R="rMeanSignal",Rb="rBGMedianSignal"),
-			bluefuse = list(G="AMPCH1",R="AMPCH2"),
-			genepix = list(R="F635 Mean",G="F532 Mean",Rb="B635 Median",Gb="B532 Median"),
-			genepix.median = list(R="F635 Median",G="F532 Median",Rb="B635 Median",Gb="B532 Median"),
-			genepix.custom = list(R="F635 Mean",G="F532 Mean",Rb="B635",Gb="B532"),
-			quantarray = list(R="ch2 Intensity",G="ch1 Intensity",Rb="ch2 Background",Gb="ch1 Background"),
-			smd.old = list(G="CH1I_MEAN",Gb="CH1B_MEDIAN",R="CH2I_MEAN",Rb="CH2B_MEDIAN"),
-			smd = list(G="Ch1 Intensity (Mean)",Gb="Ch1 Background (Median)",R="Ch2 Intensity (Mean)",Rb="Ch2 Background (Median)"),
-			spot = list(R="Rmean",G="Gmean",Rb="morphR",Gb="morphG"),
-			spot.close.open = list(R="Rmean",G="Gmean",Rb="morphR.close.open",Gb="morphG.close.open"),
-			NULL
-		)
-	} else {
-		if(!is.list(columns)) stop("columns must be a list")
-		names(columns)[names(columns)=="Gf"] <- "G"
-		names(columns)[names(columns)=="Rf"] <- "R"
-		if(is.null(columns$G) || is.null(columns$R)) stop("columns must specify foreground G and R")
-		if(!all(names(columns) %in% c("G","R","Gb","Rb"))) warning("non-standard columns specified")
-	}
-	cnames <- names(columns)
-
-#	Read first file to get nspots
-	fullname <- slides[1]
-	if(!is.null(path)) fullname <- file.path(path,fullname)
-	switch(source,
-	   quantarray = {
-		firstfield <- scan(fullname,what="",sep="\t",flush=TRUE,quiet=TRUE,blank.lines.skip=FALSE,multi.line=FALSE,allowEscapes=FALSE)
-		skip <- grep("Begin Data",firstfield)
-		if(length(skip)==0) stop("Cannot find \"Begin Data\" in image output file")
-		nspots <- grep("End Data",firstfield) - skip -2
-		obj <- read.table(fullname,skip=skip,header=TRUE,sep=sep,quote=quote,as.is=TRUE,check.names=FALSE,comment.char="",nrows=nspots,...)
-	}, arrayvision = {
-		skip <- 1
-		cn <- scan(fullname,what="",sep=sep,quote=quote,skip=1,nlines=1,quiet=TRUE,allowEscape=FALSE)
-		fg <- grep(" Dens - ",cn)
-		if(length(fg) != 2) stop(paste("Cannot find foreground columns in",fullname))
-		bg <- grep("Bkgd",cn)
-		if(length(fg) != 2) stop(paste("Cannot find background columns in",fullname))
-		columns <- list(R=fg[1],Rb=bg[1],G=fg[2],Gb=bg[2])
-		obj <- read.table(fullname,skip=skip,header=TRUE,sep=sep,quote=quote,as.is=TRUE,check.names=FALSE,comment.char="",...)
-		nspots <- nrow(obj)
-	}, bluefuse = {
-		skip <- readBlueFuseHeader(fullname)$NHeaderRecords
-		obj <- read.table(fullname,skip=skip,header=TRUE,sep=sep,quote=quote,as.is=TRUE,check.names=FALSE,comment.char= "",fill=TRUE,...)
-		nspots <- nrow(obj)
-	}, genepix=,genepix.median=,genepix.custom = {
-		h <- readGPRHeader(fullname)
-		if(verbose && source=="genepix.custom") cat("Custom background:",h$Background,"\n")
-		skip <- h$NHeaderRecords
-		obj <- read.table(fullname,skip=skip,header=TRUE,sep=sep,quote=quote,as.is=TRUE,check.names=FALSE,comment.char="",fill=TRUE,...)
-		nspots <- nrow(obj)
-	}, smd=,smd.old = {
-		skip <- readSMDHeader(fullname)$NHeaderRecords
-		obj <- read.table(fullname,skip=skip,header=TRUE,sep=sep,quote=quote,as.is=TRUE,check.names=FALSE,comment.char="",fill=TRUE,...)
-		nspots <- nrow(obj)
-	}, {
-		skip <- grep(protectMetachar(columns$R),readLines(fullname,n=80)) - 1
-		if(length(skip)==0)
-			stop("Cannot find column heading in image output file")
-		else
-			skip <- skip[1]
-		obj <- read.table(fullname,skip=skip,header=TRUE,sep=sep,quote=quote,as.is=TRUE,check.names=FALSE,comment.char="",fill=TRUE,...)
-		nspots <- nrow(obj)
-	})
-
-#	Initialize RG list object
-	Y <- matrix(0,nspots,nslides)
-	colnames(Y) <- names
-	RG <- columns
-	for (a in cnames) RG[[a]] <- Y
-	if(!is.null(wt.fun)) RG$weights <- Y
-	RG$targets <- data.frame(FileName=I(files),row.names=names)
-
-#	Set annotation information
-	if(is.null(annotation)) annotation <- switch(source,
-		agilent = c("Row","Col","Start","Sequence","SwissProt","GenBank","Primate","GenPept","ProbeUID","ControlType","ProbeName","GeneName","SystematicName","Description"),
-		bluefuse = c("ROW","COL","SUBGRIDROW","SUBGRIDCOL","BLOCK","NAME","ID"),   
-		genepix=,genepix.median=,genepix.custom = c("Block","Row","Column","ID","Name"),
-		smd = c("Spot","Clone ID","Gene Symbol","Gene Name","Cluster ID","Accession","Preferred name","Locuslink ID","Name","Sequence Type","X Grid Coordinate (within sector)","Y Grid Coordinate (within sector)","Sector","Failed","Plate Number","Plate Row","Plate Column","Clone Source","Is Verified","Is Contaminated","Luid"),
-		smd.old = c("SPOT","NAME","Clone ID","Gene Symbol","Gene Name","Cluster ID","Accession","Preferred name","SUID"),
-		NULL
-	)
-	if(!is.null(annotation)) {
-		j <- match(annotation,colnames(obj),0)
-		if(any(j>0)) RG$genes <- data.frame(obj[,j,drop=FALSE])
-	}
-
-#	Set printer layout
-	if(source=="agilent") {
-		if(!is.null(RG$genes$Row) && !is.null(RG$genes$Col)) {
-			nr <- length(unique(RG$genes$Row))
-			nc <- length(unique(RG$genes$Col))
-			if(nspots==nr*nc) RG$printer <- list(ngrid.r=1,ngrid.c=1,nspot.r=nr,nspot.c=nc)
-		}
-	}
-
-#	Other columns
-	if(!is.null(other.columns)) {
-		other.columns <- as.character(other.columns)
-		j <- match(other.columns,colnames(obj),0)
-		if(any(j>0)) {
-			other.columns <- colnames(obj)[j]
-			RG$other <- list()
-			for (j in other.columns) RG$other[[j]] <- Y 
-		} else {
-			other.columns <- NULL
-		}
-	}
-
-#	Now read remainder of files
-	for (i in 1:nslides) {
-		if(i > 1) {
-			fullname <- slides[i]
-			if(!is.null(path)) fullname <- file.path(path,fullname)
-			if(source %in% c("genepix","genepix.median")) skip <- readGPRHeader(fullname)$NHeaderRecords
-			if(source=="genepix.custom") {
-				h <- readGPRHeader(fullname)
-				if(verbose) cat("Custom background:",h$Background,"\n")
-				skip <- h$NHeaderRecords
-			}
-			if(source=="bluefuse") skip <- readBlueFuseHeader(fullname)$NHeaderRecords
-            obj <- read.table(fullname,skip=skip,header=TRUE,sep=sep,as.is=TRUE,quote=quote,check.names=FALSE,comment.char="",fill=TRUE,nrows=nspots,...)
-		}
-		for (a in cnames) RG[[a]][,i] <- obj[,columns[[a]]]
-		if(!is.null(wt.fun)) RG$weights[,i] <- wt.fun(obj)
-		if(!is.null(other.columns)) for (j in other.columns) {
-			RG$other[[j]][,i] <- obj[,j] 
-		}
-		if(verbose) cat(paste("Read",fullname,"\n"))
-	}
-	new("RGList",RG)
-}
-
-read.imagene <- function(files,path=NULL,ext=NULL,names=NULL,columns=NULL,wt.fun=NULL,verbose=TRUE,sep="\t",quote="\"",...) {
-#	Extracts an RG list from a series of Imagene analysis output files.
-#	Imagene requires special treatment because red and green channel
-#	intensities are in different files.
-#	Gordon Smyth
-#	14 Aug 2003.  Last modified 18 September 2005.
-
-	if(is.null(dim(files))) {
-		if(length(files)%%2==0)
-			files <- matrix(files, ncol=2, byrow=TRUE)
-		else
-			stop("Odd number of files: should be two data files for each array")
-	} else {
-		files <- as.matrix(files)
-		if(ncol(files) != 2) stop("Need a two column matrix of file names")
-	}
-	if(!is.null(ext)) files <- array(paste(files,ext,sep="."),dim(files))
-	narrays <- nrow(files)
-	if(is.null(columns)) columns <- list(f="Signal Mean",b="Background Median")
-	if(is.null(columns$f) || is.null(columns$b)) stop("'columns' should have components 'f' and 'b'")
-	if(is.null(names)) names <- removeExt(files[,1])
-
-#	Read header information from first file to get nspots
-	fullname <- files[1,1]
-	if(!is.null(path)) fullname <- file.path(path,fullname)
-	headers <- readImaGeneHeader(fullname)
-	if(verbose) cat("Read header information\n")
-	skip <- headers$NHeaderRecords
-	FD <- headers[["Field Dimensions"]]
-	nspots <- prod(FD)
-
-#	Now read data
-	Y <- matrix(0,nspots,narrays)
-	colnames(Y) <- names
-	RG <- list(R=Y,G=Y,Rb=Y,Gb=Y,Image.Program="ImaGene",Field.Dimensions=FD)
-	if(!is.null(wt.fun)) RG$weights <- Y
-	if(nrow(FD)==1) {
-		RG$printer <- list(ngrid.r=FD[1,"Metarows"],ngrid.c=FD[1,"Metacols"],nspot.r=FD[1,"Rows"],nspot.c=FD[1,"Cols"])
-	}
-	for (i in 1:narrays) {
-		fullname <- files[i,1]
-		if(!is.null(path)) fullname <- file.path(path,fullname)
-		if(i > 1) {
-			headers <- readImaGeneHeader(fullname)
-			if(any(headers[["Field Dimensions"]] != RG$Field.Dimensions))
-				stop(paste("Field dimensions of array",i,"not same as those of first array"))
-			skip <- headers$NHeaderRecords
-		}
-		obj<- read.table(fullname,skip=skip,header=TRUE,sep=sep,quote=quote,check.names=FALSE,comment.char="",fill=TRUE,nrows=nspots,...)
-		if(verbose) cat(paste("Read",fullname,"\n"))
-		if(i==1) RG$genes <- obj[,c("Field","Meta Row","Meta Column","Row","Column","Gene ID")]
-		RG$G[,i] <- obj[,columns$f]
-		RG$Gb[,i] <- obj[,columns$b]
-		fullname <- files[i,2]
-		if(!is.null(path)) fullname <- file.path(path,fullname)
-		obj<- read.table(fullname,skip=skip,header=TRUE,sep=sep,quote=quote,check.names=FALSE,comment.char="",fill=TRUE,nrows=nspots,...)
-		if(verbose) cat(paste("Read",fullname,"\n"))
-		RG$R[,i] <- obj[,columns$f]
-		RG$Rb[,i] <- obj[,columns$b]
-		if(!is.null(wt.fun)) RG$weights[,i] <- wt.fun(obj)
-	}
-	new("RGList",RG)
-}
-
 readGPRHeader <- function(file) {
 #	Extracts header information from a GenePix Results (GPR) file
 #	Gordon Smyth
